@@ -150,4 +150,16 @@ RCT_EXPORT_METHOD(setTrackUncaughtExceptions:(BOOL)enabled)
     [GAI sharedInstance].trackUncaughtExceptions = enabled;
 }
 
+RCT_EXPORT_METHOD(setAnonymizeIp:(BOOL)enabled)
+{
+    id<GAITracker> tracker = [[GAI sharedInstance] defaultTracker];
+    [tracker set:kGAIAnonymizeIp value:enabled ? @"1" : @"0"];
+}
+
+RCT_EXPORT_METHOD(setOptOut:(BOOL)enabled)
+{
+    [GAI sharedInstance].optOut = enabled;
+}
+
+
 @end
